#MSUB -r moistc_rmssp126
#MSUB -o moistc_rmssp126.out_%I
#MSUB -e moistc_rmssp126.out_%I
#MSUB -n 1
#MSUB -T 36000
#MSUB -q xlarge
#MSUB -c 8
#MSUB -Q normal
#MSUB -A gen0239
#MSUB -m store,work,scratch
##MSUB -A ls3cmip6 
set -vx
#!/bin/bash

# Script to create nudging files for soil moisture climatology derived from 30 year running mean
# This creates running mean climatology of the soil moisture with daily frequency, starting with 
# the historical siumlation and then using one scenario.
#
# 1. Daily output for the years 1980-2014 from the simulation CM61-LR-hist-03.1910 and for the years
#    2015-210O from sceanario simulation CM61-LR-scen-ssp126 or CM61-LR-scen-585 are used
# 2. The variable moistc is first splitted into moistc_1, moistc_2, moistc_3 to remove the axes on soiltiles.
# 3. For years with 366 days, the 31 of decembre is removed to enable making the median over all years.
# 4. For each year in the intervall 1994-2085, the median is calculated using 30years in total with the current year in the middle. 
#    For the first 15 years 1980-1995: the median for the first 30years will be used => running median for year 1994
#    For the last 15 years 2085-2100: the median for the last 30years will be used => running meadian for year 2085
# 5. For each year, the last day is duplicated to have 366 days in each file. 
#
# $HeadURL$
# $Date$
# $Revision$
#######################################################################################################################
date
JobName=CM61-LR-hist-03.1910
ssp=ssp126
#ssp=ssp585
JobNameScen=CM61-LR-scen-${ssp}
mkdir run_moistc_rm_${JobName}_${JobNameScen}
cd run_moistc_rm_${JobName}_${JobNameScen}

echo Start
# 1. historical r1: CM61-LR-hist-03.1910
simulpathHist=/ccc/store/cont003/gencmip6/p86caub/IGCM_OUT/IPSLCM6/PROD/historical/CM61-LR-hist-03.1910/SRF/Output/DA
simulpathScen=/ccc/store/cont003/gencmip6/oboucher/IGCM_OUT/IPSLCM6/PROD/${ssp}/${JobNameScen}/SRF/Output/DA

allpackHist=" 19800101_19891231 19900101_19991231 20000101_20091231 20100101_20141231 "
allpackScen=" 20150101_20241231 20250101_20341231 20350101_20441231 20450101_20541231 20550101_20641231 20650101_20741231 20750101_20841231 20850101_20941231 20950101_21001231 "

# 2. Extract moistc
#    First from historical simulation and then also from scenario simulation
echo Extract variable moistc from packed files
# float moistc(time_counter, soiltyp, solay, lat, lon)

for pack in ${allpackHist} ; do
  echo Treat file ${simulpathHist}/${JobName}_${pack}_DA_sechiba_out_2.nc
  ncks -v moistc ${simulpathHist}/${JobName}_${pack}_DA_sechiba_out_2.nc moistc_${pack}_DA_sechiba_out_2.nc
done

for pack in ${allpackScen} ; do
  echo Treat file ${simulpathScen}/${JobNameScen}_${pack}_DA_sechiba_out_2.nc
  ncks -v moistc ${simulpathScen}/${JobNameScen}_${pack}_DA_sechiba_out_2.nc moistc_${pack}_DA_sechiba_out_2.nc
done


echo Separate into variables per soiltile, for historical and scenario
for pack in ${allpackHist} ${allpackScen} ; do
  ncks -d soiltyp,0,0 moistc_${pack}_DA_sechiba_out_2.nc moistc1_${pack}_DA_sechiba_out_2.nc
  ncks -d soiltyp,1,1 moistc_${pack}_DA_sechiba_out_2.nc moistc2_${pack}_DA_sechiba_out_2.nc
  ncks -d soiltyp,2,2 moistc_${pack}_DA_sechiba_out_2.nc moistc3_${pack}_DA_sechiba_out_2.nc

  ncrename -v moistc,moistc_1 moistc1_${pack}_DA_sechiba_out_2.nc
  ncrename -v moistc,moistc_2 moistc2_${pack}_DA_sechiba_out_2.nc
  ncrename -v moistc,moistc_3 moistc3_${pack}_DA_sechiba_out_2.nc
done


echo "Remove dimension soiltyp (which is now 1) by averaging over the dimension. Put all variables in the same file."

for pack in ${allpackHist} ${allpackScen} ; do
  for soiltyp in 1 2 3 ; do
    ncwa -A -a soiltyp  moistc${soiltyp}_${pack}_DA_sechiba_out_2.nc moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  done
  ncatted -a long_name,moistc_1,m,c,"Soil Moisture profile for soil tile 1" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  ncatted -a long_name,moistc_2,m,c,"Soil Moisture profile for soil tile 2" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  ncatted -a long_name,moistc_3,m,c,"Soil Moisture profile for soil tile 3" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
done

echo "Separate per year"
for pack in ${allpackHist} ${allpackScen} ; do
  cdo splityear moistc_allsoil_${pack}_DA_sechiba_out_2.nc moistc_
done


# 3. Remove one time step in leap years
echo "Remove last time step (31 of december) from leap years"
allleap=" 1980 1984 1988 1992 1996 2000 2004 2008 2012 "
allleapScen=" 2016 2020 2024 2028 2032 2036 2040 2044 2048 2052 2056 2060 2064 2068 2072 2076 2080 2084 2088 2092 2096 "
for year in $allleap ${allleapScen} ; do
  mv moistc_${year}.nc moistc_${year}.leap.nc 
  ncks -d time_counter,0,364 moistc_${year}.leap.nc moistc_${year}.365.nc 
  cp moistc_${year}.365.nc moistc_${year}.nc 
done

# 4. Calculate running median over 30 years 
echo "Calculate median"

# For the first 15 years 1980-1995: take median for the first 30years => running median for year 1994
# For the last 15 years 2085-2100: take median for the last 30years => running meadian for year 2085
# For the years in between, take the median using 14 years before, the current year and 15 years after

# Calculate here the running median for the years 1994-2085
year=1994
lastyear=2085
while [ ${year} -le ${lastyear} ] ; do
  echo year=${year}
  # Determine the list of files for 14 years before, the current year and 15 years after current year
  y1=$(( ${year} - 15 ))
  y2=$(( ${year} + 15 ))
  filelist=""
  while [ ${y1} -le ${y2} ] ; do
    filelist="$filelist moistc_${y1}.nc "
    let y1=${y1}+1
  done
  echo for year=$year filelist= $filelist

  echo "Calculate median for year=$year using files: $filelist "
  cdo enspctl,50 $filelist moistc_30yrm_${year}.nc 


  # 5. Duplicate last day to make a file with 366days
  echo "Duplicate last day to make a file with 366days"
  # Extract last day
  cdo seltimestep,365 moistc_30yrm_${year}.nc moistc_clim_365.nc
  # Switch time axis one day ahead
  ncatted -O -a units,time_counter,m,c,"seconds since 1850-01-02 00:00:00"  moistc_clim_365.nc 
  # Merge with clim file
  ncrcat moistc_30yrm_${year}.nc moistc_clim_365.nc moistc_30yrm_${year}.nc 

  let year=${year}+1
done


echo End

